@@ -14,6 +14,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDLIBRARY': '-L. -lpython3.8',
  'BLDSHARED': 'gcc -pthread -shared '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+              '-fno-semantic-interposition '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -22,34 +23,37 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
+           '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
            '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
            '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
-           '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt -march=armv6 '
-           '-mfloat-abi=hard -mfpu=vfp -O3 -pipe -fstack-protector-strong '
-           '-fno-plt',
+           '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                     '-fstack-protector-strong -fno-plt',
+                     '-fstack-protector-strong -fno-plt '
+                     '-fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                      '-fno-semantic-interposition',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
-                "'--with-computed-gotos' '--without-lto' '--enable-ipv6' "
-                "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
-                "'--with-system-ffi' '--with-system-libmpdec' "
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
+                "'--without-lto' '--enable-ipv6' '--with-system-expat' "
+                "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
+                "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'CFLAGS=-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe "
-                "-fstack-protector-strong -fno-plt' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
-                "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+                '-fstack-protector-strong -fno-plt '
+                "-fno-semantic-interposition' "
+                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
+                "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
@@ -532,12 +536,14 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+            '-fno-semantic-interposition '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.8.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+             '-fno-semantic-interposition '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'LDVERSION': '3.8',
  'LIBC': '',
@@ -633,8 +639,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv6 -mfloat-abi=hard '
                              '-mfpu=vfp -O3 -pipe -fstack-protector-strong '
-                             '-fno-plt -march=armv6 -mfloat-abi=hard -mfpu=vfp '
-                             '-O3 -pipe -fstack-protector-strong -fno-plt '
+                             '-fno-plt -fno-semantic-interposition '
+                             '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
                              '-pipe -fstack-protector-strong -fno-plt -std=c99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
@@ -645,10 +652,10 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-              '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
-              '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt '
+              '-fstack-protector-strong -fno-plt -fno-semantic-interposition '
               '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-              '-fstack-protector-strong -fno-plt',
+              '-fstack-protector-strong -fno-plt -march=armv6 -mfloat-abi=hard '
+              '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
@@ -656,10 +663,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -march=armv6 '
-                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
-                   '-fstack-protector-strong -fno-plt -march=armv6 '
-                   '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
+                   '-fstack-protector-strong -fno-plt '
+                   '-fno-semantic-interposition -march=armv6 -mfloat-abi=hard '
+                   '-mfpu=vfp -O3 -pipe -fstack-protector-strong -fno-plt '
+                   '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
@@ -667,17 +674,20 @@ build_time_vars = {'ABIFLAGS': '',
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+                    '-fno-semantic-interposition '
                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+               '-fno-semantic-interposition '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv6 -mfloat-abi=hard -mfpu=vfp -O3 '
-                        '-pipe -fstack-protector-strong -fno-plt -march=armv6 '
+                        '-pipe -fstack-protector-strong -fno-plt '
+                        '-fno-semantic-interposition -march=armv6 '
                         '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
                         '-fstack-protector-strong -fno-plt -march=armv6 '
                         '-mfloat-abi=hard -mfpu=vfp -O3 -pipe '
